@@ -97,59 +97,6 @@ def test_get_embedding_function_init_exception():
         )
 
 
-@pytest.mark.asyncio
-async def test_try_server_versions():
-    # Test successful v1 response
-    with patch("httpx.AsyncClient") as mock_client:
-        mock_response = MagicMock()
-        mock_response.status_code = 200
-        mock_client.return_value.__aenter__.return_value.get.return_value = (
-            mock_response
-        )
-        assert await try_server("http://localhost:8300") is True
-        mock_client.return_value.__aenter__.return_value.get.assert_called_once_with(
-            url="http://localhost:8300/api/v1/heartbeat"
-        )
-
-    # Test fallback to v2 when v1 fails
-    with patch("httpx.AsyncClient") as mock_client:
-        mock_response_v1 = MagicMock()
-        mock_response_v1.status_code = 404
-        mock_response_v2 = MagicMock()
-        mock_response_v2.status_code = 200
-        mock_client.return_value.__aenter__.return_value.get.side_effect = [
-            mock_response_v1,
-            mock_response_v2,
-        ]
-        assert await try_server("http://localhost:8300") is True
-        assert mock_client.return_value.__aenter__.return_value.get.call_count == 2
-
-    # Test both versions fail
-    with patch("httpx.AsyncClient") as mock_client:
-        mock_response_v1 = MagicMock()
-        mock_response_v1.status_code = 404
-        mock_response_v2 = MagicMock()
-        mock_response_v2.status_code = 500
-        mock_client.return_value.__aenter__.return_value.get.side_effect = [
-            mock_response_v1,
-            mock_response_v2,
-        ]
-        assert await try_server("http://localhost:8300") is False
-
-    # Test connection error cases
-    with patch("httpx.AsyncClient") as mock_client:
-        mock_client.return_value.__aenter__.return_value.get.side_effect = (
-            httpx.ConnectError("Cannot connect")
-        )
-        assert await try_server("http://localhost:8300") is False
-
-    with patch("httpx.AsyncClient") as mock_client:
-        mock_client.return_value.__aenter__.return_value.get.side_effect = (
-            httpx.ConnectTimeout("Connection timeout")
-        )
-        assert await try_server("http://localhost:8300") is False
-
-
 def test_verify_ef():
     # Mocking AsyncCollection and Config
     mock_collection = MagicMock()
@@ -190,10 +137,18 @@ async def test_try_server_mocked(mock_socket):
     with patch("httpx.AsyncClient") as mock_client:
         mock_response = MagicMock()
         mock_response.status_code = 200
+        mock_response.content = b'{"info":{"title": "Chroma"}}'
         mock_client.return_value.__aenter__.return_value.get.return_value = (
             mock_response
         )
         assert await try_server("http://localhost:8000") is True
+    with patch("httpx.AsyncClient") as mock_client:
+        mock_response = MagicMock()
+        mock_response.status_code = 404
+        mock_client.return_value.__aenter__.return_value.get.return_value = (
+            mock_response
+        )
+        assert await try_server("http://localhost:8000") is False
 
     # Mocking httpx.AsyncClient to raise a ConnectError
     with patch("httpx.AsyncClient") as mock_client:
@@ -202,6 +157,15 @@ async def test_try_server_mocked(mock_socket):
         )
         assert await try_server("http://localhost:8000") is False
 
+    with patch("httpx.AsyncClient") as mock_client:
+        mock_response = MagicMock()
+        mock_response.status_code = 200
+        mock_response.content = b'{"info":{"title": "Dummy"}}'
+        mock_client.return_value.__aenter__.return_value.get.return_value = (
+            mock_response
+        )
+        assert await try_server("http://localhost:8000") is False
+
     # Mocking httpx.AsyncClient to raise a ConnectTimeout
     with patch("httpx.AsyncClient") as mock_client:
         mock_client.return_value.__aenter__.return_value.get.side_effect = (
@@ -509,6 +473,7 @@ async def test_wait_for_server_timeout():
 
 @pytest.mark.asyncio
 async def test_client_manager_get_client():
+    ClientManager().clear()
     config = Config(
         db_url="https://test_host:1234", db_path="test_db", project_root="test_proj"
     )
@@ -529,13 +494,12 @@ async def test_client_manager_get_client():
         patch("chromadb.AsyncHttpClient") as MockAsyncHttpClient,
         patch("vectorcode.common.try_server", return_value=True),
     ):
-        mock_client = MagicMock(spec=AsyncClientAPI)
+        mock_client = MagicMock(spec=AsyncClientAPI, parent=AsyncClientAPI)
         MockAsyncHttpClient.return_value = mock_client
 
         async with (
-            ClientManager().get_client(config) as client,
+            ClientManager().get_client(config),
         ):
-            assert isinstance(client, AsyncClientAPI)
             MockAsyncHttpClient.assert_called()
             assert (
                 MockAsyncHttpClient.call_args.kwargs["settings"].chroma_server_host
@@ -560,7 +524,6 @@ async def test_client_manager_get_client():
                 ClientManager().get_client(config1) as client1,
                 ClientManager().get_client(config1_alt) as client1_alt,
             ):
-                assert isinstance(client1, AsyncClientAPI)
                 MockAsyncHttpClient.assert_called()
                 assert (
                     MockAsyncHttpClient.call_args.kwargs["settings"].chroma_server_host
@@ -596,11 +559,11 @@ async def test_client_manager_list_server_processes():
         tempfile.TemporaryDirectory() as temp_dir,
         patch("vectorcode.common.start_server", side_effect=_start_server),
         patch("vectorcode.common.try_server", side_effect=_try_server),
+        patch("vectorcode.common.ClientManager._create_client"),
     ):
         db_path = os.path.join(temp_dir, "db")
         os.makedirs(db_path, exist_ok=True)
 
-        ClientManager._create_client = AsyncMock()
         async with ClientManager().get_client(
             Config(
                 db_url="http://test_host:8001",
